@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012 Guus Sliepen
-Copyright (C) 2012, 2015-2020 Layla Marchant <diligentcircle@riseup.net>
+Copyright (C) 2012, 2015-2020 The Diligent Circle <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -1110,8 +1110,8 @@ void aliens_init()
 				barrierSpeed++;
 			}
 
-			if ((game.area == MISN_POSWIC) &&
-				(aliens[i].classDef == CD_BOSS))
+			if ((game.area == MISN_POSWIC)
+					&& (aliens[i].classDef == CD_BOSS))
 			{
 				aliens[i].flags |= FL_IMMORTAL;
 			}
@@ -1144,8 +1144,8 @@ void aliens_init()
 		aliens[ALIEN_BOSS_PART2].dx = -20;
 		aliens[ALIEN_BOSS_PART2].dy = 37;
 	}
-	else if ((game.area == MISN_ELAMALE) ||
-		(game.area == MISN_FELLON))
+	else if ((game.area == MISN_ELAMALE)
+			|| (game.area == MISN_FELLON))
 	{
 		aliens[ALIEN_BOSS].target = &player;
 		aliens[ALIEN_BOSS].x = -screen->w / 2;
@@ -1194,8 +1194,8 @@ int alien_add()
 {
 	int index = alien_getFreeIndex();
 
-	if ((index == -1) || (game.area == MISN_JUPITER) ||
-			(game.area == MISN_VENUS))
+	if ((index == -1) || (game.area == MISN_JUPITER)
+			|| (game.area == MISN_VENUS))
 		return 0;
 
 	int *alienArray;
@@ -1663,8 +1663,8 @@ void alien_setKlineAI(Object *alien)
 	switch(RANDRANGE(0, 9))
 	{
 		case 0:
-			if ((alien->weaponType[0] != W_DIRSHOCKMISSILE) &&
-					(alien->weaponType[1] != W_MICRO_HOMING_MISSILES))
+			if ((alien->weaponType[0] != W_DIRSHOCKMISSILE)
+					&& (alien->weaponType[1] != W_MICRO_HOMING_MISSILES))
 				alien->flags |= FL_CONTINUOUS_FIRE;
 			alien->dx = ((alien->x - alien->target->x) /
 				((300 / alien->speed)  + RANDRANGE(0, 100)));
@@ -1674,9 +1674,9 @@ void alien_setKlineAI(Object *alien)
 		case 1:
 		case 2:
 			// Kline only attacks when he is ready!
-			if ((!(alien->flags & FL_NOFIRE)) &&
-					((game.area == MISN_ELAMALE) ||
-						game.difficulty != DIFFICULTY_ORIGINAL))
+			if ((!(alien->flags & FL_NOFIRE))
+					&& ((game.area == MISN_ELAMALE)
+						|| game.difficulty != DIFFICULTY_ORIGINAL))
 				alien->flags |= FL_DROPMINES;
 			break;
 		case 3:
@@ -1726,8 +1726,8 @@ void alien_searchForTarget(Object *alien)
 		}
 		else
 		{
-			if ((targetEnemy->classDef != CD_CARGOSHIP) &&
-					(targetEnemy->classDef != CD_BOSS))
+			if ((targetEnemy->classDef != CD_CARGOSHIP)
+					&& (targetEnemy->classDef != CD_BOSS))
 			{
 				badTarget = 1;
 			}
@@ -1743,8 +1743,8 @@ void alien_searchForTarget(Object *alien)
 			if (targetEnemy->classDef == CD_BOSS)
 				return;
 
-			if ((targetEnemy->flags & FL_DISABLED) ||
-					(targetEnemy->flags & FL_NOFIRE))
+			if ((targetEnemy->flags & FL_DISABLED)
+					|| (targetEnemy->flags & FL_NOFIRE))
 				badTarget = 1;
 		}
 	}
@@ -1815,8 +1815,8 @@ int alien_checkTarget(Object *alien)
 		return 1;
 
 	// Not at the correct vertical height
-	if ((alien->y < alien->target->y - 15) ||
-			(alien->y > alien->target->y + alien->target->image[0]->h + 15))
+	if ((alien->y < alien->target->y - 15)
+			|| (alien->y > alien->target->y + alien->target->image[0]->h + 15))
 		return 0;
 
 	return 1;
@@ -1830,11 +1830,11 @@ int alien_enemiesInFront(Object *alien)
 {
 	for (int i = 0 ; i < ALIEN_MAX ; i++)
 	{
-		if ((alien != &aliens[i]) && (aliens[i].flags & FL_WEAPCO) &&
-			(aliens[i].shield > 0))
+		if ((alien != &aliens[i]) && (aliens[i].flags & FL_WEAPCO)
+				&& (aliens[i].shield > 0))
 		{
-			if ((alien->y > aliens[i].y - 15) &&
-				(alien->y < aliens[i].y + aliens[i].image[0]->h + 15))
+			if ((alien->y > aliens[i].y - 15)
+					&& (alien->y < aliens[i].y + aliens[i].image[0]->h + 15))
 			{
 				if ((alien->face == 1) && (aliens[i].x < alien->x))
 					return 1;
@@ -1859,7 +1859,7 @@ void alien_move(Object *alien)
 
 	if (alien->owner == alien)
 	{
-		if (alien->flags & FL_CIRCLES)
+		if ((alien->flags & FL_CIRCLES) && (!(alien->flags & FL_LEAVESECTOR)))
 		{
 			if (alien->face == 0)
 			{
@@ -1886,14 +1886,18 @@ void alien_move(Object *alien)
 	{
 		for (int i = 0 ; i < ALIEN_MAX ; i++)
 		{
-			if ((aliens[i].owner != alien) && (aliens[i].active) &&
-					(aliens[i].shield > 0) && (!(aliens[i].flags & FL_LEAVESECTOR)) &&
-					(alien->classDef != CD_BARRIER) &&
-					ship_collision(alien, &aliens[i]))
+			if ((aliens[i].owner != alien) && (aliens[i].active)
+					&& (aliens[i].shield > 0)
+					&& (!(aliens[i].flags & FL_LEAVESECTOR))
+					&& (alien->classDef != CD_BARRIER)
+					&& ship_collision(alien, &aliens[i]))
 			{
-				if ((game.difficulty == DIFFICULTY_ORIGINAL) && (alien->classDef != CD_DRONE) &&
-						(alien->classDef != CD_ASTEROID) && (alien->classDef != CD_ASTEROID2) &&
-						(alien->owner == alien) && (game.area != MISN_ELLESH))
+				if ((game.difficulty == DIFFICULTY_ORIGINAL)
+						&& (alien->classDef != CD_DRONE)
+						&& (alien->classDef != CD_ASTEROID)
+						&& (alien->classDef != CD_ASTEROID2)
+						&& (alien->owner == alien)
+						&& (game.area != MISN_ELLESH))
 				{
 					collided = 1;
 				}
@@ -1978,8 +1982,8 @@ void alien_destroy(Object *alien, Object *attacker)
 	audio_playSound(SFX_EXPLOSION, alien->x, alien->y);
 
 	// Chain reaction damage if needed (Classic Difficulty version)
-	if ((game.difficulty == DIFFICULTY_ORIGINAL) &&
-			(alien->owner != alien) && (alien->flags & FL_DAMAGEOWNER))
+	if ((game.difficulty == DIFFICULTY_ORIGINAL)
+			&& (alien->owner != alien) && (alien->flags & FL_DAMAGEOWNER))
 	{
 		alien_hurt(alien->owner, attacker, alien->maxShield, 0);
 	}
@@ -2015,8 +2019,8 @@ void alien_destroy(Object *alien, Object *attacker)
 				}
 			}
 
-			if (CHANCE(1 / 16.) && (alien->flags & FL_WEAPCO) &&
-				(!(alien->flags & FL_NOBANTER)))
+			if (CHANCE(1 / 16.) && (alien->flags & FL_WEAPCO)
+					&& (!(alien->flags & FL_NOBANTER)))
 			{
 				radio_getRandomMessage(msg, _(
 					/// Chris brag messages
@@ -2048,8 +2052,8 @@ void alien_destroy(Object *alien, Object *attacker)
 		else if (attacker->classDef == CD_PHOEBE)
 		{
 			game.wingMate1Kills++;
-			if (CHANCE(1 / 8.) && (alien-> flags & FL_WEAPCO) &&
-				(!(alien->flags & FL_NOBANTER)))
+			if (CHANCE(1 / 8.) && (alien-> flags & FL_WEAPCO)
+					&& (!(alien->flags & FL_NOBANTER)))
 			{
 				radio_getRandomMessage(msg, _(
 					/// Phoebe brag messages
@@ -2077,8 +2081,8 @@ void alien_destroy(Object *alien, Object *attacker)
 		else if (attacker->classDef == CD_URSULA)
 		{
 			game.wingMate2Kills++;
-			if (CHANCE(1 / 8.) && (alien-> flags & FL_WEAPCO) &&
-				(!(alien->flags & FL_NOBANTER)))
+			if (CHANCE(1 / 8.) && (alien-> flags & FL_WEAPCO)
+					&& (!(alien->flags & FL_NOBANTER)))
 			{
 				radio_getRandomMessage(msg, _(
 					/// Ursula brag messages
@@ -2190,15 +2194,14 @@ void alien_hurt(Object *alien, Object *attacker, int damage, int ion)
 		if (game.area == MISN_ELAMALE)
 		{
 			if (game.difficulty == DIFFICULTY_ORIGINAL)
-				stage1_shield = alien->maxShield * 3 / 8;
+				stage1_shield = KLINE_SHIELD_MEDIUM;
 			else
-				stage1_shield = alien->maxShield / 4;
+				stage1_shield = KLINE_SHIELD_SMALL;
 
 			if ((alien->shield <= alien->maxShield - stage1_shield)
 				&& !(alien->flags & FL_LEAVESECTOR))
 			{
 				alien->flags |= FL_LEAVESECTOR;
-				alien->flags &= ~FL_CIRCLES;
 				/// Dialog (Kline Kethlan)
 				/// Used when Kline is beaten in the Elamale mission.
 				radio_setMessage(FS_KLINE, _("Seems I underestimated you, Bainfield. We'll meet again!"), 1);
@@ -2207,15 +2210,14 @@ void alien_hurt(Object *alien, Object *attacker, int damage, int ion)
 		else if (game.area == MISN_EARTH)
 		{
 			if (game.difficulty == DIFFICULTY_ORIGINAL)
-				stage1_shield = alien->maxShield / 4;
+				stage1_shield = KLINE_SHIELD_SMALL;
 			else
-				stage1_shield = alien->maxShield * 3 / 8;
+				stage1_shield = KLINE_SHIELD_MEDIUM;
 
 			if ((alien->shield <= alien->maxShield - stage1_shield)
 				&& !(alien->flags & FL_LEAVESECTOR))
 			{
 				alien->flags |= FL_LEAVESECTOR;
-				alien->flags &= ~FL_CIRCLES;
 				/// Dialog (Sid Wilson)
 				/// Used when Kline is beaten in the Earth mission.
 				radio_setMessage(FS_SID, _("Chris, Kethlan is getting away!"), 1);
@@ -2223,9 +2225,9 @@ void alien_hurt(Object *alien, Object *attacker, int damage, int ion)
 		}
 		else if (game.area == MISN_VENUS)
 		{
-			stage1_shield = alien->maxShield * 3 / 4;
-			stage2_shield = alien->maxShield / 2;
-			stage3_shield = alien->maxShield / 4;
+			stage1_shield = KLINE_STAGE1_SHIELD;
+			stage2_shield = KLINE_STAGE2_SHIELD;
+			stage3_shield = KLINE_STAGE3_SHIELD;
 
 			if (alien->shield + damage > stage1_shield
 					&& alien->shield <= stage1_shield)
@@ -2251,13 +2253,12 @@ void alien_hurt(Object *alien, Object *attacker, int damage, int ion)
 		}
 		else
 		{
-			stage1_shield = alien->maxShield / 20;
+			stage1_shield = KLINE_SHIELD_TINY;
 
 			if ((alien->shield <= alien->maxShield - stage1_shield)
 				&& !(alien->flags & FL_LEAVESECTOR))
 			{
 				alien->flags |= FL_LEAVESECTOR;
-				alien->flags &= ~FL_CIRCLES;
 			}
 		}
 	}
