@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2012, 2014-2020 Layla Marchant <diligentcircle@riseup.net>
+Copyright (C) 2012, 2014-2020 The Diligent Circle <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -175,12 +175,7 @@ void game_init()
 	player.weaponType[0] = W_PLAYER_WEAPON;
 	player.weaponType[1] = W_ROCKETS;
 
-	for (int i = 0 ; i < STARS_NUM ; i++)
-	{
-		stars[i].x = rand() % screen->w;
-		stars[i].y = rand() % screen->h;
-		stars[i].speed = 1 + (rand() % 3);
-	}
+	game_setStars();
 
 	weapons_init();
 	mission_init();
@@ -228,6 +223,19 @@ static void game_addDebris(int x, int y, int amount)
 	}
 }
 
+/*
+Sets star positions. Must do this any time the window size changes.
+*/
+void game_setStars()
+{
+	for (int i = 0 ; i < STARS_NUM ; i++)
+	{
+		stars[i].x = rand() % screen->w;
+		stars[i].y = rand() % screen->h;
+		stars[i].speed = 1 + (rand() % 3);
+	}
+}
+
 /*
 Simply draws the stars in their positions on screen and moves
 them around.
@@ -294,10 +302,10 @@ static void game_doCollectables()
 
 		if (collectable->active)
 		{
-			if ((collectable->x + collectable->image->w > 0) &&
-					(collectable->x < screen->w) &&
-					(collectable->y + collectable->image->h > 0) &&
-					(collectable->y < screen->h))
+			if ((collectable->x + collectable->image->w > 0)
+					&& (collectable->x < screen->w)
+					&& (collectable->y + collectable->image->h > 0)
+					&& (collectable->y < screen->h))
 				screen_blit(collectable->image, (int)collectable->x, (int)collectable->y);
 
 			collectable->x += engine.ssx + engine.smx;
@@ -567,9 +575,9 @@ static void game_doCollectables()
 		if (collectable->life < 1)
 		{
 			collectable->active = 0;
-			if ((collectable->type == P_CARGO) ||
-					(collectable->type == P_ESCAPEPOD) ||
-					(collectable->type == P_SLAVES))
+			if ((collectable->type == P_CARGO)
+					|| (collectable->type == P_ESCAPEPOD)
+					|| (collectable->type == P_SLAVES))
 				mission_updateRequirements(M_PROTECT_PICKUP, collectable->type, 1);
 		}
 
@@ -580,9 +588,9 @@ static void game_doCollectables()
 		}
 		else
 		{
-			if ((collectable->type == P_MINE) && (collectable->x >= 0) &&
-					(collectable->x <= screen->w) && (collectable->y >= 0) &&
-					(collectable->y <= screen->h))
+			if ((collectable->type == P_MINE) && (collectable->x >= 0)
+					&& (collectable->x <= screen->w) && (collectable->y >= 0)
+					&& (collectable->y <= screen->h))
 				collectable_explode(collectable);
 			prevCollectable->next = collectable->next;
 			free(collectable);
@@ -708,8 +716,8 @@ static void game_doBullets()
 					okayToHit = 1;
 				if ((bullet->flags & WF_WEAPCO) && (aliens[i].flags & FL_FRIEND))
 					okayToHit = 1;
-				if ((bullet->id == WT_ROCKET) || (bullet->id == WT_LASER) ||
-						(bullet->id == WT_CHARGER))
+				if ((bullet->id == WT_ROCKET) || (bullet->id == WT_LASER)
+						|| (bullet->id == WT_CHARGER))
 					okayToHit = 1;
 
 				if (bullet->owner == aliens[i].owner)
@@ -815,11 +823,12 @@ static void game_doBullets()
 			}
 
 			// Check for bullets hitting player
-			if ((bullet->flags & WF_WEAPCO) || (bullet->id == WT_ROCKET) ||
-				(bullet->id == WT_LASER) || (bullet->id == WT_CHARGER))
+			if ((bullet->flags & WF_WEAPCO) || (bullet->id == WT_ROCKET)
+				|| (bullet->id == WT_LASER) || (bullet->id == WT_CHARGER))
 			{
-				if (bullet->active && (player.shield > 0) &&
-					(bullet->owner != &player) && bullet_collision(bullet, &player))
+				if (bullet->active && (player.shield > 0)
+						&& (bullet->owner != &player)
+						&& bullet_collision(bullet, &player))
 				{
 					old_shield = player.shield;
 
@@ -1024,14 +1033,16 @@ static void game_doAliens()
 					if (aliens[i].face == 0)
 						aliens[i].x = aliens[i].owner->x - aliens[i].dx;
 					else
-						aliens[i].x = aliens[i].owner->x + aliens[i].owner->image[0]->w + aliens[i].dx - aliens[i].image[0]->w;
+						aliens[i].x = (aliens[i].owner->x + aliens[i].dx
+								+ aliens[i].owner->image[0]->w
+								- aliens[i].image[0]->w);
 
 					aliens[i].y = (aliens[i].owner->y + aliens[i].dy);
 
 					if (aliens[i].owner->shield < 1)
 					{
-						if ((aliens[i].classDef != CD_URANUSBOSSWING1) &&
-							(aliens[i].classDef != CD_URANUSBOSSWING2))
+						if ((aliens[i].classDef != CD_URANUSBOSSWING1)
+								&& (aliens[i].classDef != CD_URANUSBOSSWING2))
 						{
 							aliens[i].shield = 0;
 						}
@@ -1052,8 +1063,8 @@ static void game_doAliens()
 					aliens[i].target = &aliens[i];
 
 				// Specific to Sid to stop him pissing about(!)
-				if ((aliens[i].classDef == CD_SID) &&
-						(aliens[i].target->flags & FL_DISABLED))
+				if ((aliens[i].classDef == CD_SID)
+						&& (aliens[i].target->flags & FL_DISABLED))
 					aliens[i].target = &aliens[i];
 
  				if (aliens[i].target == &aliens[i])
@@ -1072,9 +1083,9 @@ static void game_doAliens()
 					}
 				}
 
-				if ((!(aliens[i].flags & FL_DISABLED)) &&
-					(aliens[i].thinktime == 0) && (aliens[i].target != &aliens[i]) &&
-					(aliens[i].owner == &aliens[i]))
+				if ((!(aliens[i].flags & FL_DISABLED))
+					&& (aliens[i].thinktime == 0) && (aliens[i].target != &aliens[i])
+					&& (aliens[i].owner == &aliens[i]))
 				{
 					if (aliens[i].classDef == CD_KLINE)
 						alien_setKlineAI(&aliens[i]);
@@ -1101,9 +1112,9 @@ static void game_doAliens()
 					if (aliens[i].x > aliens[i].target->x) aliens[i].face = 1;
 				}
 
-				if ((game.area == MISN_ELLESH) &&
-						((aliens[i].classDef == CD_BOSS) ||
-						    (game.difficulty != DIFFICULTY_ORIGINAL)))
+				if ((game.area == MISN_ELLESH)
+						&& ((aliens[i].classDef == CD_BOSS)
+						    || (game.difficulty != DIFFICULTY_ORIGINAL)))
 					aliens[i].face = 0;
 
 				if ((aliens[i].flags & FL_DEPLOYDRONES) && ((rand() % 300) == 0))
@@ -1122,8 +1133,8 @@ static void game_doAliens()
 
 					if (aliens[i].x >= 5000)
 					{
-						aliens[i].flags -= FL_LEAVESECTOR;
-						aliens[i].flags += FL_ESCAPED;
+						aliens[i].flags &= ~FL_LEAVESECTOR;
+						aliens[i].flags |= FL_ESCAPED;
 						aliens[i].active = 0;
 
 						if (aliens[i].classDef == CD_CLOAKFIGHTER)
@@ -1163,9 +1174,9 @@ static void game_doAliens()
 					aliens[i].dy = 20 + (cosf(barrierLoop + aliens[i].speed) * 40);
 				}
 
-				if ((aliens[i].classDef == CD_MOBILESHIELD) &&
-						(aliens[ALIEN_BOSS].active) &&
-						(aliens[ALIEN_BOSS].shield > 0))
+				if ((aliens[i].classDef == CD_MOBILESHIELD)
+						&& (aliens[ALIEN_BOSS].active)
+						&& (aliens[ALIEN_BOSS].shield > 0))
 				{
 					LIMIT_ADD(aliens[ALIEN_BOSS].shield, 1, 0,
 						aliens[ALIEN_BOSS].maxShield);
@@ -1174,14 +1185,14 @@ static void game_doAliens()
 				LIMIT_ADD(aliens[i].reload[0], -1, 0, 999);
 				LIMIT_ADD(aliens[i].reload[1], -1, 0, 999);
 
-				if ((!(aliens[i].flags & FL_DISABLED)) &&
-						(!(aliens[i].flags & FL_NOFIRE)))
+				if ((!(aliens[i].flags & FL_DISABLED))
+						&& (!(aliens[i].flags & FL_NOFIRE)))
 				{
 					if ((aliens[i].target->shield > 0))
 						canFire = alien_checkTarget(&aliens[i]);
 
-					if (((aliens[i].thinktime % 2) == 0) &&
-							(aliens[i].flags & FL_FRIEND))
+					if (((aliens[i].thinktime % 2) == 0)
+							&& (aliens[i].flags & FL_FRIEND))
 						canFire = alien_enemiesInFront(&aliens[i]);
 				}
 				else
@@ -1193,12 +1204,12 @@ static void game_doAliens()
 				{
 					for (int j = 0 ; j < 2 ; j++)
 					{
-						if ((aliens[i].reload[j] == 0) &&
-							((rand() % 1000 < aliens[i].chance[j]) ||
-								(aliens[i].flags & FL_CONTINUOUS_FIRE)))
+						if ((aliens[i].reload[j] == 0)
+								&& ((rand() % 1000 < aliens[i].chance[j])
+									|| (aliens[i].flags & FL_CONTINUOUS_FIRE)))
 						{
-							if ((aliens[i].weaponType[j] != W_ENERGYRAY) &&
-								(aliens[i].weaponType[j] != W_LASER))
+							if ((aliens[i].weaponType[j] != W_ENERGYRAY)
+									&& (aliens[i].weaponType[j] != W_LASER))
 							{
 								if (aliens[i].weaponType[j] == W_CHARGER)
 									aliens[i].ammo[j] = 50 + rand() % 150;
@@ -1211,8 +1222,8 @@ static void game_doAliens()
 							// Note: ammo[0] is required whether the ray is primary
 							// or secondary because futher below, ammo[0] increases on
 							// any alien that isn't currently firing a ray.
-							else if ((aliens[i].weaponType[j] == W_ENERGYRAY) &&
-								(aliens[i].ammo[0] >= RAY_INTERVAL))
+							else if ((aliens[i].weaponType[j] == W_ENERGYRAY)
+									&& (aliens[i].ammo[0] >= RAY_INTERVAL))
 							{
 								aliens[i].flags += FL_FIRERAY;
 								audio_playSound(SFX_ENERGYRAY, aliens[i].x, aliens[i].y);
@@ -1259,16 +1270,17 @@ static void game_doAliens()
 
 				LIMIT_ADD(aliens[i].hit, -1, 0, 100);
 
-				if ((aliens[i].x + aliens[i].image[0]->w > 0) &&
-					(aliens[i].x < screen->w) &&
-					(aliens[i].y + aliens[i].image[0]->h > 0) &&
-					(aliens[i].y < screen->h))
+				if ((aliens[i].x + aliens[i].image[0]->w > 0)
+						&& (aliens[i].x < screen->w)
+						&& (aliens[i].y + aliens[i].image[0]->h > 0)
+						&& (aliens[i].y < screen->h))
 				{
-					if ((!(aliens[i].flags & FL_DISABLED)) &&
-							(aliens[i].classDef != CD_ASTEROID) &&
-							(aliens[i].classDef != CD_ASTEROID2))
+					if ((!(aliens[i].flags & FL_DISABLED))
+							&& (aliens[i].classDef != CD_ASTEROID)
+							&& (aliens[i].classDef != CD_ASTEROID2))
 						explosion_addEngine(&aliens[i]);
-					if ((!(aliens[i].flags & FL_ISCLOAKED)) || (aliens[i].hit > 0))
+					if ((!(aliens[i].flags & FL_ISCLOAKED))
+							|| (aliens[i].hit > 0))
 						screen_blit(gfx_shipSprites[shapeToUse], (int)aliens[i].x,
 							(int)aliens[i].y);
 					if (aliens[i].flags & FL_DISABLED)
@@ -1320,8 +1332,8 @@ static void game_doAliens()
 			}
 
 			// Adjust the movement even whilst exploding
-			if ((!(aliens[i].flags & FL_NOMOVE)) &&
-					(!(aliens[i].flags & FL_DISABLED)))
+			if ((!(aliens[i].flags & FL_NOMOVE))
+					&& (!(aliens[i].flags & FL_DISABLED)))
 				alien_move(&aliens[i]);
 
 			if ((game.area != MISN_ELLESH) || (aliens[i].shield < 0))
@@ -1360,8 +1372,9 @@ static void game_doPlayer()
 
 			if ((engine.keyState[KEY_ALTFIRE]) && (player.weaponType[1] != W_NONE))
 			{
-				if ((player.weaponType[1] != W_CHARGER) &&
-					(player.weaponType[1] != W_LASER) && (player.ammo[1] > 0))
+				if ((player.weaponType[1] != W_CHARGER)
+						&& (player.weaponType[1] != W_LASER)
+						&& (player.ammo[1] > 0))
 				{
 					ship_fireBullet(&player, 1);
 				}
@@ -1386,9 +1399,9 @@ static void game_doPlayer()
 
 			if (player.weaponType[1] == W_CHARGER)
 			{
-				if (engine.keyState[KEY_ALTFIRE] &&
-					((game.difficulty == DIFFICULTY_ORIGINAL) ||
-						!(engine.keyState[KEY_FIRE])))
+				if (engine.keyState[KEY_ALTFIRE]
+						&& ((game.difficulty == DIFFICULTY_ORIGINAL)
+							|| !(engine.keyState[KEY_FIRE])))
 				{
 					if (!player_chargerFired)
 					{
@@ -1424,8 +1437,9 @@ static void game_doPlayer()
 
 			if ((engine.keyState[KEY_SWITCH]))
 			{
-				if ((weapons[W_PLAYER_WEAPON].ammo[0] >= 3) &&
-					(weapons[W_PLAYER_WEAPON].ammo[0] <= game.maxPlasmaOutput))
+				if ((weapons[W_PLAYER_WEAPON].ammo[0] >= 3)
+					&& ((weapons[W_PLAYER_WEAPON].ammo[0] <= game.maxPlasmaOutput)
+						|| (game.difficulty == DIFFICULTY_ORIGINAL)))
 				{
 					weapons[W_PLAYER_WEAPON].flags ^= WF_SPREAD;
 
@@ -1470,9 +1484,9 @@ static void game_doPlayer()
 
 			if (engine.keyState[KEY_ESCAPE])
 			{
-				if ((engine.done == ENGINE_RUNNING) &&
-					(engine.gameSection == SECTION_GAME) &&
-					(mission.remainingObjectives1 == 0))
+				if ((engine.done == ENGINE_RUNNING)
+					&& (engine.gameSection == SECTION_GAME)
+					&& (mission.remainingObjectives1 == 0))
 				{
 					audio_playSound(SFX_FLY, screen->w / 2, screen->h / 2);
 					engine.done = ENGINE_SYSEXIT;
@@ -1486,8 +1500,8 @@ static void game_doPlayer()
 				engine.keyState[KEY_PAUSE] = 0;
 			}
 
-			if ((game.area == MISN_ELLESH) ||
-				(game.area == MISN_MARS))
+			if ((game.area == MISN_ELLESH)
+					|| (game.area == MISN_MARS))
 			{
 				player.face = 0;
 				xmoved = 1;
@@ -1575,8 +1589,8 @@ static void game_doPlayer()
 			LIMIT_ADD(player.hit, -1, 0, 100);
 
 			screen_blit(gfx_shipSprites[shapeToUse], (int)player.x, (int)player.y);
-			if ((player.maxShield > 1) && (player.shield <= engine.lowShield) &&
-					CHANCE(1. / 10))
+			if ((player.maxShield > 1) && (player.shield <= engine.lowShield)
+					&& CHANCE(player.shield > 1 ? 1. / 10 : 3. / 10))
 				explosion_add(player.x + RANDRANGE(-10, 10),
 					player.y + RANDRANGE(-10, 20), SP_SMOKE);
 		}
@@ -1601,7 +1615,7 @@ static void game_doPlayer()
 							/// following the English version only as a general guideline.  Any
 							/// number of insults is permitted.
 							"Fool.\n"
-							"And now you're nothing but a DEAD hero.\n"
+							"And now you're nothing but a DEAD hero."
 						));
 						radio_setMessage(FS_KLINE, msg, 1);
 					}
@@ -1658,8 +1672,8 @@ static void game_doPlayer()
 	LIMIT(engine.ssy, -CAMERA_MAX_SPEED, CAMERA_MAX_SPEED);
 
 	// Specific for the mission were you have to chase the Executive Transport
-	if (((game.area == MISN_ELLESH) && (player.shield > 0)) ||
-			(game.area == MISN_MARS))
+	if (((game.area == MISN_ELLESH) && (player.shield > 0))
+			|| (game.area == MISN_MARS))
 	{
 		engine.ssx = -6;
 		engine.ssy = 0;
@@ -1816,41 +1830,41 @@ static void game_doArrow(int i)
 	if (aliens[i].x + aliens[i].image[0]->w < 0)
 	{
 		if (aliens[i].y + aliens[i].image[0]->h < 0)
-			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL) &&
-				(aliens[i].flags & FL_FRIEND)) ?
-					SP_ARROW_FRIEND_NORTHWEST : SP_ARROW_NORTHWEST);
+			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL)
+					&& (aliens[i].flags & FL_FRIEND)) ?
+				SP_ARROW_FRIEND_NORTHWEST : SP_ARROW_NORTHWEST);
 		else if (aliens[i].y > screen->h)
-			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL) &&
-				(aliens[i].flags & FL_FRIEND)) ?
-					SP_ARROW_FRIEND_SOUTHWEST : SP_ARROW_SOUTHWEST);
+			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL)
+					&& (aliens[i].flags & FL_FRIEND)) ?
+				SP_ARROW_FRIEND_SOUTHWEST : SP_ARROW_SOUTHWEST);
 		else
-			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL) &&
-				(aliens[i].flags & FL_FRIEND)) ?
-					SP_ARROW_FRIEND_WEST : SP_ARROW_WEST);
+			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL)
+					&& (aliens[i].flags & FL_FRIEND)) ?
+				SP_ARROW_FRIEND_WEST : SP_ARROW_WEST);
 	}
 	else if (aliens[i].x > screen->w)
 	{
 		if (aliens[i].y + aliens[i].image[0]->h < 0)
-			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL) &&
-				(aliens[i].flags & FL_FRIEND)) ?
-					SP_ARROW_FRIEND_NORTHEAST : SP_ARROW_NORTHEAST);
+			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL)
+					&& (aliens[i].flags & FL_FRIEND)) ?
+				SP_ARROW_FRIEND_NORTHEAST : SP_ARROW_NORTHEAST);
 		else if (aliens[i].y > screen->h)
-			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL) &&
-				(aliens[i].flags & FL_FRIEND)) ?
-					SP_ARROW_FRIEND_SOUTHEAST : SP_ARROW_SOUTHEAST);
+			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL)
+					&& (aliens[i].flags & FL_FRIEND)) ?
+				SP_ARROW_FRIEND_SOUTHEAST : SP_ARROW_SOUTHEAST);
 		else
-			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL) &&
-				(aliens[i].flags & FL_FRIEND)) ?
-					SP_ARROW_FRIEND_EAST : SP_ARROW_EAST);
+			arrow = (((game.difficulty != DIFFICULTY_ORIGINAL)
+					&& (aliens[i].flags & FL_FRIEND)) ?
+				SP_ARROW_FRIEND_EAST : SP_ARROW_EAST);
 	}
 	else if (aliens[i].y + aliens[i].image[0]->h < 0)
-		arrow = (((game.difficulty != DIFFICULTY_ORIGINAL) &&
-			(aliens[i].flags & FL_FRIEND)) ?
-				SP_ARROW_FRIEND_NORTH : SP_ARROW_NORTH);
+		arrow = (((game.difficulty != DIFFICULTY_ORIGINAL)
+				&& (aliens[i].flags & FL_FRIEND)) ?
+			SP_ARROW_FRIEND_NORTH : SP_ARROW_NORTH);
 	else if (aliens[i].y > screen->h)
-		arrow = (((game.difficulty != DIFFICULTY_ORIGINAL) &&
-			(aliens[i].flags & FL_FRIEND)) ?
-				SP_ARROW_FRIEND_SOUTH : SP_ARROW_SOUTH);
+		arrow = (((game.difficulty != DIFFICULTY_ORIGINAL)
+				&& (aliens[i].flags & FL_FRIEND)) ?
+			SP_ARROW_FRIEND_SOUTH : SP_ARROW_SOUTH);
 
 	if (arrow != -1)
 	{
@@ -1908,6 +1922,7 @@ static void game_doHud()
 	int tTextIndex;
 	char text[STRMAX_SHORT];
 	float nbars; // A float for the sake of float division
+	float min_shield, max_shield;
 	float shield_pct;
 	int i;
 	int c;
@@ -2038,8 +2053,8 @@ static void game_doHud()
 			events_check();
 	}
 
-	if ((engine.timeMission) && (player.shield > 0) &&
-			((!engine.cheatTime) || (game.area == MISN_MARS)))
+	if ((engine.timeMission) && (player.shield > 0)
+			&& ((!engine.cheatTime) || (game.area == MISN_MARS)))
 	{
 		if (SDL_GetTicks() >= engine.counter)
 		{
@@ -2113,8 +2128,8 @@ static void game_doHud()
 	// Do the target's remaining shield (if required)
 	if (game.area != MISN_DORIM)
 	{
-		if ((engine.targetIndex > -1) && (aliens[engine.targetIndex].shield > 0) &&
-				(engine.targetIndex > engine.maxAliens))
+		if ((engine.targetIndex > -1) && (aliens[engine.targetIndex].shield > 0)
+				&& (engine.targetIndex > engine.maxAliens))
 		{
 			if (game.difficulty == DIFFICULTY_ORIGINAL)
 			{
@@ -2139,8 +2154,62 @@ static void game_doHud()
 			bar.x = screen->w * 11 / 16 + gfx_textSprites[tTextIndex].image->w + 10;
 			bar.y = screen->h - 50;
 			nbars = 85.;
-			shield_pct = ((float)aliens[engine.targetIndex].shield
-				/ (float)aliens[engine.targetIndex].maxShield);
+			if (engine.targetIndex == ALIEN_KLINE
+					&& game.difficulty == DIFFICULTY_ORIGINAL)
+			{
+				if (game.area == MISN_ELAMALE)
+				{
+					max_shield = aliens[engine.targetIndex].maxShield;
+					min_shield = max_shield - KLINE_SHIELD_MEDIUM;
+				}
+				else if (game.area == MISN_EARTH)
+				{
+					max_shield = aliens[engine.targetIndex].maxShield;
+					min_shield = max_shield - KLINE_SHIELD_SMALL;
+				}
+				else if (game.area == MISN_VENUS)
+				{
+					if (aliens[ALIEN_KLINE].shield > KLINE_STAGE1_SHIELD)
+					{
+						max_shield = aliens[engine.targetIndex].maxShield;
+						min_shield = KLINE_STAGE1_SHIELD;
+					}
+					else if (aliens[ALIEN_KLINE].shield > KLINE_STAGE2_SHIELD)
+					{
+						max_shield = KLINE_STAGE1_SHIELD;
+						min_shield = KLINE_STAGE2_SHIELD;
+					}
+					else if (aliens[ALIEN_KLINE].shield > KLINE_STAGE3_SHIELD)
+					{
+						max_shield = KLINE_STAGE2_SHIELD;
+						min_shield = KLINE_STAGE3_SHIELD;
+					}
+					else
+					{
+						max_shield = KLINE_STAGE3_SHIELD;
+						min_shield = 0;
+					}
+				}
+				else
+				{
+					max_shield = aliens[engine.targetIndex].maxShield;
+					min_shield = max_shield - KLINE_SHIELD_TINY;
+				}
+
+				if (min_shield > 0)
+					shield_pct = (
+						MAX((float)aliens[engine.targetIndex].shield - min_shield, 1.)
+							/ (max_shield-min_shield));
+				else
+					shield_pct = (
+						((float)aliens[engine.targetIndex].shield - min_shield)
+							/ (max_shield-min_shield));
+			}
+			else
+			{
+				shield_pct = ((float)aliens[engine.targetIndex].shield
+					/ (float)aliens[engine.targetIndex].maxShield);
+			}
 
 			for (i = 0 ; i < nbars ; i++)
 			{
@@ -2379,7 +2448,11 @@ static void game_showGameOver()
 	screen_clear(black);
 	SDL_Delay(1000);
 
+#ifdef OLD_MUSIC
+	audio_playMusic("music/Wybierak.mod", -1);
+#else
 	audio_playMusic("music/death.ogg", -1);
+#endif
 
 	int x = (screen->w - gameover->w) / 2;
 	int y = (screen->h - gameover->h) / 2;
@@ -2473,9 +2546,9 @@ int game_mainLoop()
 	if (game.hasWingMate2)
 		alien_addFriendly(ALIEN_URSULA);
 
-	if ((game.area == MISN_URUSOR) ||
-			(game.area == MISN_POSWIC) ||
-			(game.area == MISN_EARTH))
+	if ((game.area == MISN_URUSOR)
+			|| (game.area == MISN_POSWIC)
+			|| (game.area == MISN_EARTH))
 		alien_addFriendly(ALIEN_SID);
 
 	// Disable Wingmates for certain missions
@@ -2534,8 +2607,17 @@ int game_mainLoop()
 
 	if (game.area == MISN_VENUS)
 	{
-		aliens[ALIEN_KLINE].x = player.x + 1000;
-		aliens[ALIEN_KLINE].y = player.y;
+		if (game.difficulty == DIFFICULTY_ORIGINAL)
+		{
+			aliens[ALIEN_KLINE].flags |= FL_IMMORTAL | FL_NOFIRE | FL_NOMOVE;
+			aliens[ALIEN_KLINE].x = screen->w * 3 / 4;
+			aliens[ALIEN_KLINE].y = screen->h / 2;
+		}
+		else
+		{
+			aliens[ALIEN_KLINE].x = player.x + 1000;
+			aliens[ALIEN_KLINE].y = player.y;
+		}
 	}
 
 	for (int i = 0 ; i < ALIEN_MAX ; i++)
@@ -2604,8 +2686,8 @@ int game_mainLoop()
 
 	for (int i = 0 ; i < 3 ; i++)
 	{
-		if ((mission.primaryType[i] == M_DESTROY_TARGET_TYPE) &&
-				(mission.target1[i] == CD_ANY))
+		if ((mission.primaryType[i] == M_DESTROY_TARGET_TYPE)
+				&& (mission.target1[i] == CD_ANY))
 			allowableAliens = mission.targetValue1[i];
 
 		if (mission.primaryType[i] == M_DESTROY_ALL_TARGETS)
@@ -2650,41 +2732,41 @@ int game_mainLoop()
 			engine.gameSection = SECTION_INTERMISSION;
 			if (player.shield > 0)
 			{
-				if ((SDL_GetTicks() >= engine.missionCompleteTimer) &&
-					((game.difficulty == DIFFICULTY_ORIGINAL) ||
-						(game.difficulty == DIFFICULTY_NIGHTMARE) ||
-						(game.area == MISN_INTERCEPTION) ||
-						(game.area == MISN_ELLESH) ||
-						(game.area == MISN_MARS) ||
-						(mission_checkFailed()) ||
-						(collectable_numGood() <= 0) ||
-						(engine.done == ENGINE_SYSEXIT)))
+				if ((SDL_GetTicks() >= engine.missionCompleteTimer)
+						&& ((game.difficulty == DIFFICULTY_ORIGINAL)
+							|| (game.difficulty == DIFFICULTY_NIGHTMARE)
+							|| (game.area == MISN_INTERCEPTION)
+							|| (game.area == MISN_ELLESH)
+							|| (game.area == MISN_MARS)
+							|| (mission_checkFailed())
+							|| (collectable_numGood() <= 0)
+							|| (engine.done == ENGINE_SYSEXIT)))
 				{
 					if ((!mission_checkFailed()) && (game.area != MISN_VENUS))
 					{
 						player_leaveSector();
-						if ((engine.done == ENGINE_SYSEXIT) &&
-							(game.area != MISN_DORIM) &&
-							(game.area != MISN_SIVEDI))
+						if ((engine.done == ENGINE_SYSEXIT)
+								&& (game.area != MISN_DORIM)
+								&& (game.area != MISN_SIVEDI))
 						{
-							if ((aliens[ALIEN_PHOEBE].shield > 0) &&
-								(game.area != MISN_EARTH))
+							if ((aliens[ALIEN_PHOEBE].shield > 0)
+									&& (game.area != MISN_EARTH))
 							{
 								aliens[ALIEN_PHOEBE].x = player.x - 40;
 								aliens[ALIEN_PHOEBE].y = player.y - 35;
 								aliens[ALIEN_PHOEBE].face = 0;
 							}
 
-							if ((aliens[ALIEN_URSULA].shield > 0) &&
-								(game.area != MISN_EARTH))
+							if ((aliens[ALIEN_URSULA].shield > 0)
+									&& (game.area != MISN_EARTH))
 							{
 								aliens[ALIEN_URSULA].x = player.x - 40;
 								aliens[ALIEN_URSULA].y = player.y + 45;
 								aliens[ALIEN_URSULA].face = 0;
 							}
 
-							if ((game.area == MISN_URUSOR) ||
-								(game.area == MISN_POSWIC))
+							if ((game.area == MISN_URUSOR)
+									|| (game.area == MISN_POSWIC))
 							{
 								aliens[ALIEN_SID].x = player.x - 100;
 								aliens[ALIEN_SID].y = player.y;
@@ -2692,9 +2774,10 @@ int game_mainLoop()
 							}
 						}
 					}
-					else if ((game.area == MISN_VENUS) &&
-						(engine.musicVolume > 0))
+					else if ((game.area == MISN_VENUS)
+							&& (engine.musicVolume > 0))
 					{
+						player_getInput();
 						engine.keyState[KEY_UP] = 0;
 						engine.keyState[KEY_DOWN] = 0;
 						engine.keyState[KEY_LEFT] = 0;
@@ -2718,6 +2801,7 @@ int game_mainLoop()
 			}
 			else
 			{
+				player_getInput();
 				LIMIT_ADD(engine.musicVolume, -0.2, 0, 100);
 				audio_setMusicVolume(engine.musicVolume);
 				if (SDL_GetTicks() >= engine.missionCompleteTimer)
@@ -2806,8 +2890,8 @@ int game_mainLoop()
 			engine.missionCompleteTimer = SDL_GetTicks() + 7000;
 
 		// specific to Boss 1
-		if ((game.area == MISN_MOEBO) &&
-			(aliens[ALIEN_BOSS].flags & FL_ESCAPED))
+		if ((game.area == MISN_MOEBO)
+				&& (aliens[ALIEN_BOSS].flags & FL_ESCAPED))
 		{
 			audio_playSound(SFX_DEATH, aliens[ALIEN_BOSS].x, aliens[ALIEN_BOSS].y);
 			screen_clear(white);
