@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2012, 2015-2020 Layla Marchant <diligentcircle@riseup.net>
+Copyright (C) 2012, 2015-2020 The Diligent Circle <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -693,10 +693,10 @@ static int intermission_showSystem(float pos, int selectable)
 		r.y -= (intermission_planets[planet].image->h / 2);
 		screen_blit(intermission_planets[planet].image, r.x, r.y);
 
-		if (selectable &&
-			game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6,
-				r.x, r.y, intermission_planets[planet].image->w,
-				intermission_planets[planet].image->h))
+		if (selectable
+				&& game_collision(engine.cursor_x + 13, engine.cursor_y + 13,
+					6, 6, r.x, r.y, intermission_planets[planet].image->w,
+					intermission_planets[planet].image->h))
 		{
 			if (!printedName)
 			{
@@ -754,8 +754,8 @@ static void intermission_showStatus(SDL_Surface *infoSurface)
 		for (int i = TS_STATUS_HEADER + 1 ; i < TS_STATUS_FOOTER ; i++)
 		{
 			y += 20;
-			if ((i == TS_CHRIS_HEADER) || (i == TS_PHOEBE_HEADER) ||
-					(i == TS_URSULA_HEADER))
+			if ((i == TS_CHRIS_HEADER) || (i == TS_PHOEBE_HEADER)
+					|| (i == TS_URSULA_HEADER))
 				y += 25;
 
 			gfx_textSprites[i].y = y;
@@ -1318,7 +1318,11 @@ static void intermission_doOptions(SDL_Surface *optionsSurface, int x, int y)
 		if (game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, x + 187, y + 92, 45, 22))
 		{
 			engine.useMusic = 1;
+#ifdef OLD_MUSIC
+			audio_playMusic("music/3DParadise.mod", -1);
+#else
 			audio_playMusic("music/through_space.ogg", -1);
+#endif
 		}
 
 		if (game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, x + 248, y + 92, 45, 22))
@@ -1500,7 +1504,11 @@ int intermission()
 	}
 
 	if ((engine.useAudio) && (engine.useMusic))
+#ifdef OLD_MUSIC
+		audio_playMusic("music/3DParadise.mod", -1);
+#else
 		audio_playMusic("music/through_space.ogg", -1);
+#endif
 
 	/// Retain "%s" as-is.  It is replaced with the current system name.
 	snprintf(string, STRMAX_SHORT, _("System : %s"), game_systemNames[game.system]);
@@ -1729,8 +1737,8 @@ int intermission()
 			x = screen->w / 16;
 			y = screen->h - 80;
 			w = screen->w - 2 * x - 32;
-			if ((game.stationedPlanet == game.destinationPlanet) &&
-					(!intermission_planets[game.stationedPlanet].missionCompleted))
+			if ((game.stationedPlanet == game.destinationPlanet)
+					&& (!intermission_planets[game.stationedPlanet].missionCompleted))
 				screen_blit(gfx_sprites[SP_START_MISSION], x, y);
 			else if (game.stationedPlanet != game.destinationPlanet)
 				screen_blit(gfx_sprites[SP_GOTO], x, y);
@@ -1743,9 +1751,9 @@ int intermission()
 			screen_blit(gfx_sprites[SP_OPTIONS], x + 6 * w / 7, y);
 			screen_blit(gfx_sprites[SP_EXIT], x + w, y);
 
-			if (game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, x, y, 32, 32) &&
-					((game.stationedPlanet != game.destinationPlanet) ||
-						(!intermission_planets[game.stationedPlanet].missionCompleted)))
+			if (game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, x, y, 32, 32)
+					&& ((game.stationedPlanet != game.destinationPlanet)
+						|| (!intermission_planets[game.stationedPlanet].missionCompleted)))
 			{
 				if (game.stationedPlanet == game.destinationPlanet)
 					screen_blitText(TS_INFO_START_MISSION, -1, screen->h - 25);
