@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2012, 2015-2020 Layla Marchant <diligentcircle@riseup.net>
+Copyright (C) 2012, 2015-2020 The Diligent Circle <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -565,8 +565,8 @@ static void mission_killAllEnemies()
 {
 	for (int i = 0 ; i < ALIEN_MAX ; i++)
 	{
-		if ((aliens[i].flags & FL_WEAPCO) && (aliens[i].active) &&
-				(aliens[i].shield > 0))
+		if ((aliens[i].flags & FL_WEAPCO) && (aliens[i].active)
+				&& (aliens[i].shield > 0))
 			aliens[i].shield = 0;
 	}
 }
@@ -596,13 +596,13 @@ void mission_checkTimer()
 	}
 
 	// specific to Spirit Boss
-	if ((game.area == MISN_MOEBO) &&
-			(mission.completed1[0] < OB_INCOMPLETE))
+	if ((game.area == MISN_MOEBO)
+			&& (mission.completed1[0] < OB_INCOMPLETE))
 		engine.timeMission = 1;
 
 	// specific to the Asteroid belt
-	if ((game.area == MISN_MARS) &&
-		(mission.completed1[0] < OB_INCOMPLETE))
+	if ((game.area == MISN_MARS)
+			&& (mission.completed1[0] < OB_INCOMPLETE))
 	{
 		mission.completed1[0] = OB_COMPLETED;
 		mission_killAllEnemies();
@@ -616,8 +616,8 @@ static void mission_evaluate(int type, int id, int *completed, int *targetValue,
 	char message[STRMAX_SHORT];
 	char fmt[STRMAX_SHORT];
 
-	if ((*targetValue <= 0) && (type != M_PROTECT_TARGET) &&
-			(type != M_PROTECT_PICKUP))
+	if ((*targetValue <= 0) && (type != M_PROTECT_TARGET)
+			&& (type != M_PROTECT_PICKUP))
 	{
 		*completed = OB_JUST_COMPLETED;
 		mission_checkTimer();
@@ -814,9 +814,9 @@ void mission_updateRequirements(int type, int id, int value)
 	{
 		if ((mission.completed1[i] == OB_INCOMPLETE) || (mission.completed1[i] == OB_CONDITION))
 		{
-			if ((mission.primaryType[i] == type) &&
-					((mission.target1[i] == id) ||
-						(mission.target1[i] == CD_ANY)))
+			if ((mission.primaryType[i] == type)
+					&& ((mission.target1[i] == id)
+						|| (mission.target1[i] == CD_ANY)))
 			{
 				matched = 1;
 				mission.targetValue1[i] -= value;
@@ -833,9 +833,9 @@ void mission_updateRequirements(int type, int id, int value)
 	{
 		if ((mission.completed2[i] == OB_INCOMPLETE) || (mission.completed2[i] == OB_CONDITION))
 		{
-			if ((mission.secondaryType[i] == type) &&
-					((mission.target2[i] == id) ||
-						(mission.target2[i] == CD_ANY)))
+			if ((mission.secondaryType[i] == type)
+					&& ((mission.target2[i] == id)
+						|| (mission.target2[i] == CD_ANY)))
 			{
 				mission.targetValue2[i] -= value;
 				mission_evaluate(type, id, &mission.completed2[i], &mission.targetValue2[i], FONT_YELLOW);
@@ -924,7 +924,11 @@ static int mission_revealObjectives()
 			aliens[ALIEN_KLINE].y = player.y;
 			aliens[ALIEN_KLINE].flags |= FL_IMMORTAL | FL_NOFIRE;
 			player_setTarget(ALIEN_KLINE);
+#ifdef OLD_MUSIC
+			audio_playMusic("music/TranceGeneration.mod", -1);
+#else
 			audio_playMusic("music/last_cyber_dance.ogg", -1);
+#endif
 		}
 	}
 
@@ -937,7 +941,9 @@ int mission_checkCompleted()
 	{
 		if (mission.completed1[i] == OB_INCOMPLETE)
 		{
-			if ((mission.primaryType[i] == M_DESTROY_ALL_TARGETS) && (engine.allAliensDead) && (mission.remainingObjectives1 + mission.remainingObjectives2 == 1))
+			if ((mission.primaryType[i] == M_DESTROY_ALL_TARGETS)
+				&& (engine.allAliensDead)
+				&& (mission.remainingObjectives1 + mission.remainingObjectives2 == 1))
 			{
 				mission.completed1[i] = OB_JUST_COMPLETED;
 				mission_checkTimer();
@@ -949,7 +955,9 @@ int mission_checkCompleted()
 	{
 		if (mission.completed2[i] == OB_INCOMPLETE)
 		{
-			if ((mission.secondaryType[i] == M_DESTROY_ALL_TARGETS) && (engine.allAliensDead) && (mission.remainingObjectives1 + mission.remainingObjectives2 == 1))
+			if ((mission.secondaryType[i] == M_DESTROY_ALL_TARGETS)
+				&& (engine.allAliensDead)
+				&& (mission.remainingObjectives1 + mission.remainingObjectives2 == 1))
 			{
 				mission.completed2[i] = OB_JUST_COMPLETED;
 				mission_checkTimer();
@@ -983,10 +991,10 @@ int mission_checkCompleted()
 				mission.completed1[i] = OB_COMPLETED;
 
 				// do some area specific things
-				if ((game.area == MISN_MOEBO) ||
-					(game.area == MISN_DORIM) ||
-					(game.area == MISN_ELLESH) ||
-					(game.area == MISN_MARS))
+				if ((game.area == MISN_MOEBO)
+					|| (game.area == MISN_DORIM)
+					|| (game.area == MISN_ELLESH)
+					|| (game.area == MISN_MARS))
 				{
 					if (mission.remainingObjectives2 == 0)
 					{
@@ -1017,8 +1025,8 @@ int mission_checkCompleted()
 				mission.completed2[i] = OB_COMPLETED;
 
 				// do some area specific things
-				if ((game.area == MISN_DORIM) &&
-					(mission.remainingObjectives1 == 0))
+				if ((game.area == MISN_DORIM)
+						&& (mission.remainingObjectives1 == 0))
 				{
 					mission_killAllEnemies();
 					engine.addAliens = -1;
@@ -1222,17 +1230,17 @@ void mission_showStartScreen()
 					break;
 			}
 
-			if ((game.area == MISN_URUSOR) ||
-					(game.area == MISN_POSWIC) ||
-					(game.area == MISN_EARTH))
+			if ((game.area == MISN_URUSOR)
+					|| (game.area == MISN_POSWIC)
+					|| (game.area == MISN_EARTH))
 				screen_renderUnicode(_("Sid Wilson will join you on this mission"), screen->w / 2 - BRIEFING_WIDTH / 2 + 20, screen->h / 2 + 175, FONT_WHITE);
 
 			renderer_update();
 
 			game_delayFrame();
 			player_getInput();
-			if ((engine.keyState[KEY_FIRE]) || (engine.keyState[KEY_ALTFIRE]) ||
-					(engine.keyState[KEY_ESCAPE]))
+			if ((engine.keyState[KEY_FIRE]) || (engine.keyState[KEY_ALTFIRE])
+					|| (engine.keyState[KEY_ESCAPE]))
 				break;
 		}
 
