@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2012, 2015-2020 Layla Marchant <diligentcircle@riseup.net>
+Copyright (C) 2012, 2015-2020 The Diligent Circle <diligentcircle@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -266,7 +266,7 @@ int title_show()
 		5, 0, FONT_WHITE, 0, copyrightText);
 	gfx_renderString("Copyright Guus Sliepen, Astrid S. de Wijn and others 2012",
 		5, MENU_SPACING, FONT_WHITE, 0, copyrightText);
-	gfx_renderString("Copyright 2015-2020 Layla Marchant",
+	gfx_renderString("Copyright 2015-2020 The Diligent Circle",
 		5, 2 * MENU_SPACING, FONT_WHITE, 0, copyrightText);
 
 	snprintf(buildVersion, STRMAX_SHORT, "Version %s", VERSION );
@@ -313,7 +313,11 @@ int title_show()
 	player_flushInput();
 	engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
 
+#ifdef OLD_MUSIC
+	audio_playMusic("music/Platinum.mod", 1);
+#else
 	audio_playMusic("music/walking_among_androids.ogg", 1);
+#endif
 
 	while (!engine.done)
 	{
@@ -510,7 +514,11 @@ int title_show()
 
 							if (engine.useMusic)
 							{
+#ifdef OLD_MUSIC
+								audio_playMusic("music/Platinum.mod", 1);
+#else
 								audio_playMusic("music/walking_among_androids.ogg", 1);
+#endif
 							}
 							else
 							{
@@ -643,7 +651,11 @@ void title_showCredits()
 
 	screen_drawBackground();
 
+#ifdef OLD_MUSIC
+	audio_playMusic("music/Solace.s3m", 1);
+#else
 	audio_playMusic("music/rise_of_spirit.ogg", 1);
+#endif
 
 	fp = fopen("data/credits.txt", "rb");
 
@@ -695,9 +707,16 @@ void title_showCredits()
 		screen_unBuffer();
 
 		player_getInput();
-		if (engine.keyState[KEY_ESCAPE] || engine.keyState[KEY_FIRE] ||
-				engine.keyState[KEY_ALTFIRE])
+		if (engine.keyState[KEY_ESCAPE] || engine.keyState[KEY_FIRE]
+				|| engine.keyState[KEY_ALTFIRE])
 			break;
+		
+		// Check to see if we need to reposition credits
+		if (credit[0].x != (screen->w - credit[0].image->w) / 2) {
+			for (i=0; i< nCredit; i++) {
+				credit[i].x = (screen->w - credit[i].image->w) / 2;
+			}
+		}
 
 		float speed = 0.5;
 		if (engine.keyState[KEY_DOWN])
